Index: content/browser/renderer_host/render_process_host_impl.cc |
diff --git a/content/browser/renderer_host/render_process_host_impl.cc b/content/browser/renderer_host/render_process_host_impl.cc |
index 93ce6b0a0f0c16ccc612460f3955de37ca23fc57..75fd0257e7b46f220515340c45c6c17e2c0a0570 100644 |
--- a/content/browser/renderer_host/render_process_host_impl.cc |
+++ b/content/browser/renderer_host/render_process_host_impl.cc |
@@ -861,9 +861,10 @@ bool RenderProcessHostImpl::Init() { |
if (channel_) |
return true; |
// Ensure that the RouteProvider proxy is re-initialized on next access since |
// it's associated with a specific Channel instance. |
remote_route_provider_.reset(); |
+ renderer_interface_.reset(); |
base::CommandLine::StringType renderer_prefix; |
// A command prefix is something prepended to the command line of the spawned |
@@ -1419,6 +1420,14 @@ mojom::RouteProvider* RenderProcessHostImpl::GetRemoteRouteProvider() { |
return remote_route_provider_.get(); |
} |
+mojom::Renderer* RenderProcessHostImpl::GetRendererInterface() { |
+ if (!renderer_interface_) { |
+ DCHECK(channel_); |
+ channel_->GetRemoteAssociatedInterface(&renderer_interface_); |
+ } |
+ return renderer_interface_.get(); |
+} |
+ |
void RenderProcessHostImpl::AddRoute(int32_t routing_id, |
IPC::Listener* listener) { |
CHECK(!listeners_.Lookup(routing_id)) << "Found Routing ID Conflict: " |
@@ -861,9 +861,10 @@ bool RenderProcessHostImpl::Init() { |
if (channel_) |
return true; |
- // Ensure that the RouteProvider proxy is re-initialized on next access since |
- // it's associated with a specific Channel instance. |
+ // Ensure that the remote associated interfaces are re-initialized on next |
+ // access since they're associated with a specific Channel instance. |
remote_route_provider_.reset(); |